@@ -5,7 +5,7 @@ for i in *.func; do source $i; done
 function main
 {
 	# test if the user is root
-	if [ ! $UID = 0 ]
+	if [ $(id -u) -ne 0 ]
 	then
 		echo 'Error: no permission (user is not root)'
 		exit 1
@@ -27,6 +27,8 @@ function main
 	mounting_partition
 
 	# lfs chapter 3
+	optimize_packages
+
 	if [ ! -d $LFSINSTALL_CACHE ]
 	then
 		download_packages
@@ -39,7 +41,6 @@ function main
 	fi
 
 	# lfs chapter 5
-	optimize_packages
 	precompile_packages
 
 	# lfs chapter 6
@@ -57,6 +58,7 @@ function main
 	# lfs-install cdrom
 	echo -n 'Build cdrom: '
 	read cdrom
+
 	if [ $cdrom = y ]
 	then
 		build_cdrom
